WeatherRegime <- function(data, EOFS = FALSE, neofs = NULL, ncenters = NULL, method = "kmeans",
                          nstart = 30, detrend = FALSE, pldegree = NULL, posTR = NULL, listindex = NULL) {
  sdate <- which(names(dim(data)) == "sdate")
  ftime <- which(names(dim(data)) == "ftime")
  lon <- which(names(dim(data)) == "lon")
  lat <- which(names(dim(data)) == "lat")
  dims <- c(1 : length(dim(data)))[-c(sdate, ftime, lon, lat)]
  data <- aperm(data, c(sdate, ftime, lat, lon, dims))
  if (is.null(ncenters)) {
    stop("nclusters must be specified")
  }
  if (detrend == TRUE) {
    if (is.null(pldegree)) {
      pldegree <- 1
    }
    data <- Trend(data, posTR = posTR, pldegree = pldegree)$detrend
  }
  if (EOFS  == TRUE) {
    n.lats <- dim(data)[lat]
    n.lons <- dim(data)[lon]
    wghts <- cos(lat * pi/180) ** 0.5
    data <- apply(data, MARGIN = c(1,2), fun(x) x * wghts)
    subs <- seq(1, n.lats * n.lons, 16) # select only 1 point of 9
    data <- melt(data, varnames = c("Year", "Day", "Lat", "Lon"))
    data <- acast(data, Year + Day ~ Lat + Lon)
    data <- princomp(data[,subs], cor = FALSE)$scores
    print(dim(data))
  } else {
    data <- melt(data, varnames = c("Year", "Day", "Lat", "Lon"))
    data <- unname(acast(data, Year + Day ~ Lat + Lon))
  }
  if (method == "kmeans") {
    result <- kmeans(data, centers = ncenters, iter.max = 100, nstart= nstart, trace=FALSE)
  }
}
  

